:orphan:

`plasmapy.analysis.time_series.excess_statistics`
=================================================

.. currentmodule:: plasmapy.analysis.time_series.excess_statistics

.. automodapi:: plasmapy.analysis.time_series.excess_statistics
